@@ -59,6 +59,8 @@ BaseConfigurationDialog::BaseConfigurationDialog( QWidget* parent, Configuration
 
     // restore default
     _buttonBox().addButton( QDialogButtonBox::RestoreDefaults );
+    _buttonBox().button( QDialogButtonBox::RestoreDefaults )->setText( tr( "Defaults" ) );
+    _buttonBox().button( QDialogButtonBox::RestoreDefaults )->setIcon( IconEngine::get( IconNames::Revert ) );
     _buttonBox().button( QDialogButtonBox::RestoreDefaults )->setToolTip( tr( "Restore default value for all options" ) );
 
     connect( _buttonBox().button( QDialogButtonBox::RestoreDefaults ), SIGNAL(clicked()), SLOT(_restoreDefaults()) );
@@ -67,6 +69,7 @@ BaseConfigurationDialog::BaseConfigurationDialog( QWidget* parent, Configuration
     // reset
     _buttonBox().addButton( QDialogButtonBox::Reset );
     _buttonBox().button( QDialogButtonBox::Reset )->setToolTip( tr( "Reset configuration" ) );
+    _buttonBox().button( QDialogButtonBox::Reset )->setIcon( IconEngine::get( IconNames::Undo ) );
     connect( _buttonBox().button( QDialogButtonBox::Reset ), SIGNAL(clicked()), SLOT(_reset()) );
     connect( _buttonBox().button( QDialogButtonBox::Reset ), SIGNAL(clicked()), SIGNAL(reset()) );
 
@@ -575,7 +578,7 @@ bool BaseConfigurationDialog::_findModification( const Options& first, const Opt
 
                 Debug::Throw(0) << "BaseConfigurationDialog::_findModification - special option " << firstIter.key() << " does not match" << endl;
                 Debug::Throw(0) << "BaseConfigurationDialog::_findModification - could not find: " << option << endl;
-                Debug::Throw(0) << "BaseConfigurationDialog::_findModification -  first values: " << firstIter.value() << endl;
+                Debug::Throw(0) << "BaseConfigurationDialog::_findModification - first values: " << firstIter.value() << endl;
                 Debug::Throw(0) << "BaseConfigurationDialog::_findModification - second values: " << options << endl;
                 return true;
             }
