@@ -221,7 +221,7 @@ QRect IconView::visualRect( const QModelIndex&  index ) const
 QSize IconView::minimumSizeHint( void ) const
 {
     return QSize(
-        2*margin_ + 2*IconViewItem::margin + qMax( IconViewItem::maxTextWidth, pixmapSize_.width() ) + verticalScrollBar()->width(),
+        2*margin_ + 2*IconViewItem::margin + qMax( IconViewItem::maxTextWidth, iconSize().width() ) + verticalScrollBar()->width(),
         QAbstractItemView::minimumSize().height() );
 }
 
@@ -660,31 +660,12 @@ void IconView::mousePressEvent( QMouseEvent* event )
 
     const bool shiftPressed( event->modifiers() & Qt::ShiftModifier );
     const QModelIndex index = indexAt( event->pos() );
-    if( !index.isValid() )
+    if( index.isValid() )
     {
 
-        Debug::Throw( "IconView::mousePressEvent - single selection - rubberband mode.\n" );
-
-        if( !shiftPressed )
-        {
-            selectionModel()->clear();
-            anchorIndex_ = QModelIndex();
-        }
-
-        if( !rubberBand_ ) rubberBand_ = new QRubberBand(QRubberBand::Rectangle, viewport());
-        rubberBand_->setGeometry( QRect( dragOrigin_, QSize() ) );
-        rubberBand_->show();
-
-        QAbstractItemView::mousePressEvent( event );
-        setState( DragSelectingState );
-
-
-    } else {
-
         // drag
         if( selectionModel()->isSelected( index ) && dragEnabled() && !shiftPressed )
         {
-            Debug::Throw( "IconView::mousePressEvent - single selection - drag mode.\n" );
             anchorIndex_ = index;
             return QAbstractItemView::mousePressEvent( event );
         }
@@ -700,20 +681,11 @@ void IconView::mousePressEvent( QMouseEvent* event )
 
         } else {
 
-            Debug::Throw( "IconView::mousePressEvent - single selection.\n" );
-
             anchorIndex_ = index;
             selectionModel()->clear();
             selectionModel()->setCurrentIndex( index, QItemSelectionModel::Current );
             selectionModel()->select( index, QItemSelectionModel::Select|QItemSelectionModel::Rows );
 
-            if( !dragEnabled() )
-            {
-                if( !rubberBand_ ) rubberBand_ = new QRubberBand(QRubberBand::Rectangle, viewport());
-                rubberBand_->setGeometry( QRect( dragOrigin_, QSize() ) );
-                rubberBand_->show();
-            }
-
             // ensure proper state is set
             QAbstractItemView::mousePressEvent( event );
             setState( dragEnabled() ? DraggingState : DragSelectingState );
@@ -721,6 +693,19 @@ void IconView::mousePressEvent( QMouseEvent* event )
 
         }
 
+    } else {
+
+        // clear selection
+        if( !shiftPressed )
+        {
+            selectionModel()->clear();
+            anchorIndex_ = QModelIndex();
+        }
+
+        // default processing
+        QAbstractItemView::mousePressEvent( event );
+        setState( DragSelectingState );
+
     }
 
 
@@ -730,9 +715,12 @@ void IconView::mousePressEvent( QMouseEvent* event )
 void IconView::mouseMoveEvent( QMouseEvent *event )
 {
 
-    if( dragButton_ == Qt::LeftButton && rubberBand_ && rubberBand_->isVisible() )
+    if( dragButton_ == Qt::LeftButton && ( event->buttons() & Qt::LeftButton ) && !( dragEnabled() && indexAt( dragOrigin_ ).isValid() ) )
     {
 
+        if( !rubberBand_ ) rubberBand_ = new QRubberBand(QRubberBand::Rectangle, viewport());
+        if( !rubberBand_->isVisible() ) rubberBand_->show();
+
         // disable hover index
         _setHoverIndex( QModelIndex() );
 
@@ -754,7 +742,9 @@ void IconView::mouseMoveEvent( QMouseEvent *event )
 
         // default implementation
         _setHoverIndex( indexAt( event->pos() ) );
-        QAbstractItemView::mouseMoveEvent(event);
+
+        if( event->buttons() & Qt::LeftButton )
+        { QAbstractItemView::mouseMoveEvent(event); }
 
     }
 
@@ -880,8 +870,9 @@ void IconView::_updateItem( IconViewItem& item, const QModelIndex& index ) const
     if( textVariant.canConvert( QVariant::String ) ) item.setText( textVariant.value<QString>() );
 
     // update pixmap
-    QVariant iconVariant( model()->data( index, Qt::DecorationRole ) );
-    if( iconVariant.canConvert( QVariant::Icon ) ) item.setPixmap( iconVariant.value<QIcon>().pixmap( pixmapSize_ ) );
+    QVariant decorationVariant( model()->data( index, Qt::DecorationRole ) );
+    if( decorationVariant.canConvert( QVariant::Icon ) ) item.setPixmap( decorationVariant.value<QIcon>().pixmap( iconSize() ) );
+    else if( decorationVariant.canConvert( QVariant::Pixmap ) ) item.setPixmap( decorationVariant.value<QPixmap>() );
 
 }
 
@@ -1386,10 +1377,15 @@ void IconView::_updateConfiguration( void )
     updateSortOrder();
 
     // update pixmap size
-    int pixmapSize( 0 );
-    if( XmlOptions::get().contains( "ICON_VIEW_PIXMAP_SIZE" ) && (pixmapSize = XmlOptions::get().get<int>( "ICON_VIEW_PIXMAP_SIZE" )) != pixmapSize_.width() )
+    int iconSize( 0 );
+    if( iconSizeFromOptions_ && XmlOptions::get().contains( "ICON_VIEW_ICON_SIZE" ) && (iconSize = XmlOptions::get().get<int>( "ICON_VIEW_ICON_SIZE" )) != this->iconSize().width() )
     {
-        pixmapSize_ = QSize( pixmapSize, pixmapSize );
+        QAbstractItemView::setIconSize( QSize( iconSize, iconSize ) );
+
+        #if QT_VERSION < 0x050000
+        emit iconSizeChanged( this->iconSize() );
+        #endif
+
         if( model() ) doItemsLayout();
     }
 }
