@@ -130,6 +130,10 @@ class TextEditor: public BaseEditor, public Base::Key, public Counter
     bool lineNumbersFromOptions( void ) const
     { return lineNumberFromOptions_; }
 
+    //* block highlight from options
+    bool highlightBlockFromOptions( void ) const
+    { return highlightBlockFromOptions_; }
+
     //* tab character
     virtual const QString& tabCharacter( void ) const
     { return tab_; }
@@ -263,6 +267,10 @@ class TextEditor: public BaseEditor, public Base::Key, public Counter
     void setLineNumbersFromOptions( bool value )
     { lineNumberFromOptions_ = value; }
 
+    //* block highlight from options
+    void setHighlightBlockFromOptions( bool value )
+    { highlightBlockFromOptions_ = value; }
+
     //* true if should track anchors (html links)
     virtual void setTrackAnchors( bool );
 
@@ -325,6 +333,14 @@ class TextEditor: public BaseEditor, public Base::Key, public Counter
     QAction& pasteAction( void ) const
     { return *pasteAction_;  }
 
+    //* select all
+    QAction& selectAllAction( void ) const
+    { return *selectAllAction_; }
+
+    //* clear
+    QAction& clearAction( void ) const
+    { return *clearAction_; }
+
     //* convert selection to upper case
     QAction& lowerCaseAction( void ) const
     { return *upperCaseAction_; }
@@ -423,19 +439,19 @@ class TextEditor: public BaseEditor, public Base::Key, public Counter
     //* idle
     void idle( void );
 
-    //* emmitted when selection could not be found
+    //* emitted when selection could not be found
     void noMatchFound( void );
 
-    //* emmitted when selection could be found
+    //* emitted when selection could be found
     void matchFound( void );
 
-    //* emmitted when selected line is not found
+    //* emitted when selected line is not found
     void lineNotFound( void );
 
-    //* emmitted when selected line is found
+    //* emitted when selected line is found
     void lineFound( void );
 
-    //* emmited when recieve focus
+    //* emitted when recieve focus
     void hasFocus( TextEditor* );
 
     //* overwrite mode changed
@@ -508,8 +524,11 @@ class TextEditor: public BaseEditor, public Base::Key, public Counter
     //*@name event handlers
     //@{
 
+    //* generic event
+    virtual bool event( QEvent* );
+
     //* enter event handler
-    void enterEvent( QEvent *event );
+    virtual void enterEvent( QEvent *event );
 
     //* mouse release event [overloaded]
     virtual void mousePressEvent( QMouseEvent* );
@@ -702,6 +721,9 @@ class TextEditor: public BaseEditor, public Base::Key, public Counter
     //* synchronize selection
     virtual void _synchronizeSelection( void );
 
+    //* update action status
+    virtual void _updateContentActions( void );
+
     //* update action status
     virtual void _updateReadOnlyActions( bool );
 
@@ -809,12 +831,15 @@ class TextEditor: public BaseEditor, public Base::Key, public Counter
     //* true if this display is the active display
     bool active_ = false;
 
-    /** set to false when the wrapping must not get loaded via the options */
+    //* set to false when the wrapping must not get loaded via the options
     bool wrapFromOptions_ = true;
 
-    /** set to false when the display of line numbers must not get loaded via the options. */
+    //* set to false when the display of line numbers must not get loaded via the options.
     bool lineNumberFromOptions_ = true;
 
+    //* set to false when block highlighting should not be set from options
+    bool highlightBlockFromOptions_ = true;
+
     //* true if should track anchors (html links)
     bool trackAnchors_ = false;
 
