@@ -123,6 +123,18 @@ void TreeView::setItemDelegate( QAbstractItemDelegate* delegate )
 
 }
 
+//______________________________________________________________________
+void TreeView::setItemDelegateForColumn( int column, QAbstractItemDelegate* delegate )
+{
+
+    // assign new
+    QTreeView::setItemDelegateForColumn( column, delegate );
+
+    // update margin to store value
+    _setItemMargin( itemMargin_ );
+
+}
+
 //______________________________________________________________________
 void TreeView::setFindEnabled( bool value )
 {
@@ -415,6 +427,15 @@ void TreeView::_setItemMargin( int value )
     if( TreeViewItemDelegate* delegate = qobject_cast<TreeViewItemDelegate*>( itemDelegate() ) )
     { delegate->setItemMargin( itemMargin_ ); }
 
+    if( model() )
+    {
+        for( int iColumn = 0; iColumn < model()->columnCount(); ++iColumn )
+        {
+            if( TreeViewItemDelegate* delegate = qobject_cast<TreeViewItemDelegate*>( itemDelegateForColumn(iColumn) ) )
+            { delegate->setItemMargin( itemMargin_ ); }
+        }
+    }
+
 }
 
 //__________________________________________________________
@@ -961,6 +982,11 @@ void TreeView::_updateConfiguration( void )
     {
         int iconSize( XmlOptions::get().get<int>( "LIST_ICON_SIZE" ) );
         QTreeView::setIconSize( QSize( iconSize, iconSize )  );
+
+        #if QT_VERSION < 0x050000
+        emit iconSizeChanged( this->iconSize() );
+        #endif
+
     }
 
 }
