@@ -29,31 +29,19 @@ class TreeViewItemDelegate: public QStyledItemDelegate
 
     public:
 
-    //! constructor
-    TreeViewItemDelegate( QObject* parent = 0x0 ):
-        QStyledItemDelegate( parent ),
-        itemMargin_(1)
-    {}
+    //* constructor
+    TreeViewItemDelegate( QObject* = nullptr );
 
-    //! set item margin
-    virtual void setItemMargin( int value )
-    { itemMargin_ = value; }
+    //* set item margin
+    virtual void setItemMargin( int );
 
-    //! size hint for index
-    virtual QSize sizeHint( const QStyleOptionViewItem& option, const QModelIndex& index ) const
-    {
-        QSize size( QStyledItemDelegate::sizeHint( option, index ) );
-        if( size.isValid() && itemMargin_ > 0 )
-        { size.rheight() += itemMargin_*2; }
-
-        return size;
-    }
+    //* size hint for index
+    virtual QSize sizeHint( const QStyleOptionViewItem&, const QModelIndex& ) const;
 
     private:
 
-    //! margin
-    int itemMargin_;
-
+    //* margin
+    int itemMargin_ = 1;
 
 };
 
