@@ -34,10 +34,10 @@ namespace Server
         QObject( parent ),
         Counter( "ApplicationManager" ),
         host_( QHostAddress::LocalHost ),
-        port_( 8090 ),
+        port_( 8091 ),
         server_( new QTcpServer( this ) ),
         serverInitialized_( false ),
-        client_( new Client( this, new QTcpSocket( this ) ) ),
+        client_( new Client( this ) ),
         state_( AwaitingReply )
     {
 
@@ -62,11 +62,7 @@ namespace Server
 
     //_________________________________________
     ApplicationManager::~ApplicationManager( void )
-    {
-        Debug::Throw( "ApplicationManager::~ApplicationManager.\n" );
-        delete client_;
-        delete server_;
-    }
+    {}
 
     //_________________________________________
     CommandLineParser ApplicationManager::commandLineParser( CommandLineArguments arguments, bool ignoreWarnings )
@@ -104,7 +100,6 @@ namespace Server
         {
 
             QString host( parser.option( "--server-host" ) );
-            XmlOptions::get().setRaw( "SERVER_HOST", host );
             host_ = QHostAddress( host );
 
         } else host_ = QHostAddress( QString( XmlOptions::get().raw( "SERVER_HOST" ) ) );
@@ -114,7 +109,6 @@ namespace Server
         {
 
             int port( parser.option( "--server-port" ).toUInt() );
-            XmlOptions::get().set<int>( "SERVER_PORT", port );
             port_ = port;
 
         } else port_ = XmlOptions::get().get<int>( "SERVER_PORT" );
@@ -318,15 +312,14 @@ namespace Server
     void ApplicationManager::_newConnection()
     {
         Debug::Throw( "ApplicationManager::_newConnection.\n" );
-
-        // check pending connection
-        if( !server_->hasPendingConnections() ) return;
-
-        // create client from pending connection
-        Client *client( new Client( this, server_->nextPendingConnection() ) );
-        connect( client, SIGNAL(commandAvailable(Server::ServerCommand)), SLOT(_redirect(Server::ServerCommand)) );
-        connect( &client->socket(), SIGNAL(disconnected()), SLOT(_clientConnectionClosed()) );
-        _connectedClients() << client;
+        while( server_->hasPendingConnections() )
+        {
+            // create client from pending connection
+            Client *client( new Client( this, server_->nextPendingConnection() ) );
+            connect( client, SIGNAL(commandAvailable(Server::ServerCommand)), SLOT(_redirect(Server::ServerCommand)) );
+            connect( &client->socket(), SIGNAL(disconnected()), SLOT(_clientConnectionClosed()) );
+            connectedClients_ << client;
+        }
 
     }
 
