@@ -207,10 +207,6 @@ namespace SpellCheck
 
     }
 
-    //__________________________________________
-    SpellDialog::~SpellDialog( void )
-    { Debug::Throw( "SpellCheck::SpellDialog::~SpellDialog.\n" ); }
-
     //__________________________________________
     void SpellDialog::showFilter( bool value )
     {
@@ -612,8 +608,8 @@ namespace SpellCheck
     QVariant SpellDialog::Model::data( const QModelIndex &index, int role) const
     {
 
-        // check index, role and column
-        if( !index.isValid() ) return QVariant();
+        // check index
+        if( !contains( index ) ) return QVariant();
 
         // retrieve associated file info
         const QString& word( get(index) );
