@@ -21,7 +21,7 @@
 
 #include "BaseConfigurationDialog.h"
 
-//! configuration dialog
+//* configuration dialog
 class ConfigurationDialog: public BaseConfigurationDialog
 {
 
@@ -29,12 +29,8 @@ class ConfigurationDialog: public BaseConfigurationDialog
 
     public:
 
-    //! creator
-    ConfigurationDialog( QWidget *parent = 0 );
-
-    //! destructor
-    virtual ~ConfigurationDialog( void )
-    {}
+    //* creator
+    ConfigurationDialog( QWidget *parent = nullptr );
 
 };
 
