@@ -27,14 +27,14 @@
 namespace IconNames
 {
 
-    static const QString AddTab = "tab-new.png";
-    static const QString RemoveTab = "tab-close.png";
-    static const QString Record = "edit-find.png";
-    static const QString Resume = "media-playback-start.png";
-    static const QString Pause = "media-playback-pause.png";
-    static const QString Kill = "edit-delete.png";
-    static const QString Tree = "view-list-tree.png";
-    static const QString PreferencesJobTracking = "zoom-in.png";
+    static const QString AddTab = "tab-new";
+    static const QString RemoveTab = "tab-close";
+    static const QString Record = "edit-find";
+    static const QString Resume = "media-playback-start";
+    static const QString Pause = "media-playback-pause";
+    static const QString Kill = "process-stop";
+    static const QString Tree = "view-list-tree";
+    static const QString PreferencesJobTracking = "help-about";
 
 };
 
