@@ -159,10 +159,6 @@ MainWindow::MainWindow( QWidget* parent ):
     _updateConfiguration();
 }
 
-//___________________________________________
-MainWindow::~MainWindow( void )
-{ Debug::Throw( "MainWindow::~MainWindow.\n" ); }
-
 //_______________________________________
 void MainWindow::updateActions( void )
 {
@@ -614,7 +610,7 @@ void MainWindow::_removeFrame( int index )
 
     // check counts
     unsigned int counts( Base::KeySet<JobManagerFrame>( this ).size() );
-    Q_ASSERT( counts > 1 && _hasActiveFrame() );
+    Q_ASSERT( counts > 1 && hasActiveFrame() );
 
     // check frame
     Q_ASSERT( index >= 0 );
