@@ -25,7 +25,7 @@
 #include "Job.h"
 #include "JobModel.h"
 
-//! close files
+//* close files
 class SignalJobsDialog: public QuestionDialog
 {
 
@@ -33,16 +33,12 @@ class SignalJobsDialog: public QuestionDialog
 
     public:
 
-    //! constructor
+    //* constructor
     SignalJobsDialog( QWidget*, int, Job::List );
 
-    //! destructor
-    virtual ~SignalJobsDialog( void )
-    {}
-
     private:
 
-    //! model
+    //* model
     JobModel model_;
 
 };
