@@ -33,14 +33,10 @@ class SignalMenu: public QMenu, public Counter
 
     public:
 
-    //! constructor
-    SignalMenu( QWidget* = 0 );
+    //* constructor
+    SignalMenu( QWidget* = nullptr );
 
-    //! destructor
-    virtual ~SignalMenu( void )
-    {}
-
-    //! signal name matching given id
+    //* signal name matching given id
     QString signalName( int ) const;
 
     Q_SIGNALS:
@@ -49,12 +45,12 @@ class SignalMenu: public QMenu, public Counter
 
     protected Q_SLOTS:
 
-    //! request signal
+    //* request signal
     void _requestSignal( QAction* );
 
     private:
 
-    //! action map
+    //* action map
     using ActionMap = QHash< QAction*, int>;
     ActionMap actions_;
 
