@@ -30,24 +30,20 @@ class XcbInterface: public Counter
 
     public:
 
-    //! constructor
+    //* constructor
     XcbInterface( void ):
         Counter( "XcbInterface" )
     {}
 
-    //! destructor
-    virtual ~XcbInterface( void )
-    {}
-
-    //! find pixmaps for a given set of jobs
+    //* find pixmaps for a given set of jobs
     void findIcons( Job::List& ) const;
 
     protected:
 
-    //! find pixmaps, starting from window [recursive]
+    //* find pixmaps, starting from window [recursive]
     void _findIcons( WId, Job::List& ) const;
 
-    //! find icon for a given window
+    //* find icon for a given window
     QIcon _icon( WId ) const;
 
 };
